==> goods-center-biz-1.2-20160620.064014-3-sources.jar: cn/com/duiba/goods/center/biz/entity/PlatformCouponGoodsEntity.java <==
/**
 * Project Name:goods-center-biz
 * File Name:PlatformCouponGoods.java
 * Package Name:cn.com.duiba.goods.center.biz.entity
 * Date:2016年5月19日下午3:36:07
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.biz.entity;

import java.util.Date;

/**
 * ClassName:PlatformCouponGoods <br/>
 * Date:     2016年5月19日 下午3:36:07 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class PlatformCouponGoodsEntity {
    
    

    private Long id;
    
    private Long pcgId;
    
    private String title;
    
    private String name;
    
    private String subtitle;
    
    private Integer minPrice;
    
    private String usePrompt;
    
    private String buttonText;
    
    private Integer interestPrice;
    
    private String interestDesc;
    
    private String backgroundColor;
    
    private String iconImage;
    
    private String thumbnailImage;
    
    private String detailImage;
    
    private Integer couponType;
    
    private Date autoOffDate;
    
    private Integer limitPerConsumer;//每个用户最多兑换次数
    
    private Long switches;
    
    private Integer pcgStatus;
    
    private Boolean deleted;
    
    private Date gmtCreate;
    
    private Date gmtModified;

    
    public Long getId() {
        return id;
    }

    
    public void setId(Long id) {
        this.id = id;
    }

    
    public Long getPcgId() {
        return pcgId;
    }

    
    public void setPcgId(Long pcgId) {
        this.pcgId = pcgId;
    }

    
    public String getTitle() {
        return title;
    }

    
    public void setTitle(String title) {
        this.title = title;
    }

    
    public String getName() {
        return name;
    }

    
    public void setName(String name) {
        this.name = name;
    }

    
    public String getSubtitle() {
        return subtitle;
    }

    
    public void setSubtitle(String subtitle) {
        this.subtitle = subtitle;
    }

    
    public Integer getMinPrice() {
        return minPrice;
    }

    
    public void setMinPrice(Integer minPrice) {
        this.minPrice = minPrice;
    }

    
    public String getUsePrompt() {
        return usePrompt;
    }

    
    public void setUsePrompt(String usePrompt) {
        this.usePrompt = usePrompt;
    }

    
    public String getButtonText() {
        return buttonText;
    }

    
    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    
    public Integer getInterestPrice() {
        return interestPrice;
    }

    
    public void setInterestPrice(Integer interestPrice) {
        this.interestPrice = interestPrice;
    }

    
    public String getInterestDesc() {
        return interestDesc;
    }

    
    public void setInterestDesc(String interestDesc) {
        this.interestDesc = interestDesc;
    }

    
    public String getBackgroundColor() {
        return backgroundColor;
    }

    
    public void setBackgroundColor(String backgroundColor) {
        this.backgroundColor = backgroundColor;
    }

    
    public String getIconImage() {
        return iconImage;
    }

    
    public void setIconImage(String iconImage) {
        this.iconImage = iconImage;
    }

    
    public String getThumbnailImage() {
        return thumbnailImage;
    }

    
    public void setThumbnailImage(String thumbnailImage) {
        this.thumbnailImage = thumbnailImage;
    }

    
    public String getDetailImage() {
        return detailImage;
    }

    
    public void setDetailImage(String detailImage) {
        this.detailImage = detailImage;
    }

    
    public Integer getCouponType() {
        return couponType;
    }

    
    public void setCouponType(Integer couponType) {
        this.couponType = couponType;
    }

    
    public Date getAutoOffDate() {
        return autoOffDate;
    }

    
    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }

    
    public Long getSwitches() {
        return switches;
    }

    
    public void setSwitches(Long switches) {
        this.switches = switches;
    }

    
    public Integer getPcgStatus() {
        return pcgStatus;
    }

    
    public void setPcgStatus(Integer pcgStatus) {
        this.pcgStatus = pcgStatus;
    }

    
    public Boolean getDeleted() {
        return deleted;
    }

    
    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    
    public Date getGmtCreate() {
        return gmtCreate;
    }

    
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    
    public Date getGmtModified() {
        return gmtModified;
    }

    
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }


    
    public Integer getLimitPerConsumer() {
        return limitPerConsumer;
    }


    
    public void setLimitPerConsumer(Integer limitPerConsumer) {
        this.limitPerConsumer = limitPerConsumer;
    }
    
    
    
}

==> goods-center-biz-1.4.8.7-20160819.071352-1-sources.jar: cn/com/duiba/goods/center/biz/entity/PlatformCouponGoodsEntity.java <==
/**
 * Project Name:goods-center-biz
 * File Name:PlatformCouponGoods.java
 * Package Name:cn.com.duiba.goods.center.biz.entity
 * Date:2016年5月19日下午3:36:07
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.biz.entity;

import java.util.Date;

/**
 * ClassName:PlatformCouponGoods <br/>
 * Date:     2016年5月19日 下午3:36:07 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class PlatformCouponGoodsEntity {
    
    

    private Long id;
    
    private Long pcgId;
    
    private String title;
    
    private String name;
    
    private String subtitle;
    
    private Integer minPrice;
    
    private String usePrompt;
    
    private String buttonText;
    
    private String interestPrice;
    
    private String interestDesc;
    
    private String backgroundColor;
    
    private String iconImage;
    
    private String thumbnailImage;
    
    private String detailImage;
    
    private Integer couponType;
    
    private Integer facePrice;
    
    private Date autoOffDate;
    
    private Integer limitPerConsumer;//每个用户最多兑换次数
    
    private Long switches;
    
    private Integer pcgStatus;
    
    private Boolean deleted;
    
    private Date gmtCreate;
    
    private Date gmtModified;

    
//    public Long getId() {
//        return id;
//    }

    
//    public void setId(Long id) {
//        this.id = id;
//    }

    
    public Long getPcgId() {
        return pcgId;
    }

    
    public void setPcgId(Long pcgId) {
        this.pcgId = pcgId;
    }

    
    public String getTitle() {
        return title;
    }

    
    public void setTitle(String title) {
        this.title = title;
    }

    
    public String getName() {
        return name;
    }

    
    public void setName(String name) {
        this.name = name;
    }

    
    public String getSubtitle() {
        return subtitle;
    }

    
    public void setSubtitle(String subtitle) {
        this.subtitle = subtitle;
    }

    
    public Integer getMinPrice() {
        return minPrice;
    }

    
    public void setMinPrice(Integer minPrice) {
        this.minPrice = minPrice;
    }

    
    public String getUsePrompt() {
        return usePrompt;
    }

    
    public void setUsePrompt(String usePrompt) {
        this.usePrompt = usePrompt;
    }

    
    public String getButtonText() {
        return buttonText;
    }

    
    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    
    public String getInterestPrice() {
        return interestPrice;
    }

    
    public void setInterestPrice(String interestPrice) {
        this.interestPrice = interestPrice;
    }

    
    public String getInterestDesc() {
        return interestDesc;
    }

    
    public void setInterestDesc(String interestDesc) {
        this.interestDesc = interestDesc;
    }

    
    public String getBackgroundColor() {
        return backgroundColor;
    }

    
    public void setBackgroundColor(String backgroundColor) {
        this.backgroundColor = backgroundColor;
    }

    
    public String getIconImage() {
        return iconImage;
    }

    
    public void setIconImage(String iconImage) {
        this.iconImage = iconImage;
    }

    
    public String getThumbnailImage() {
        return thumbnailImage;
    }

    
    public void setThumbnailImage(String thumbnailImage) {
        this.thumbnailImage = thumbnailImage;
    }

    
    public String getDetailImage() {
        return detailImage;
    }

    
    public void setDetailImage(String detailImage) {
        this.detailImage = detailImage;
    }

    
    public Integer getCouponType() {
        return couponType;
    }

    
    public void setCouponType(Integer couponType) {
        this.couponType = couponType;
    }

    
    public Integer getFacePrice() {
        return facePrice;
    }

    
    public void setFacePrice(Integer facePrice) {
        this.facePrice = facePrice;
    }


    public Date getAutoOffDate() {
        return autoOffDate;
    }

    
    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }

    
    public Long getSwitches() {
        return switches;
    }

    
    public void setSwitches(Long switches) {
        this.switches = switches;
    }

    
    public Integer getPcgStatus() {
        return pcgStatus;
    }

    
    public void setPcgStatus(Integer pcgStatus) {
        this.pcgStatus = pcgStatus;
    }

    
    public Boolean getDeleted() {
        return deleted;
    }

    
    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    
    public Date getGmtCreate() {
        return gmtCreate;
    }

    
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    
    public Date getGmtModified() {
        return gmtModified;
    }

    
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    
    public Integer getLimitPerConsumer() {
        return limitPerConsumer;
    }
    
    public void setLimitPerConsumer(Integer limitPerConsumer) {
        this.limitPerConsumer = limitPerConsumer;
    }
    
}
